@@ -412,7 +412,7 @@ init_canvas( FL_OBJECT * ob )
         XClearWindow( flx->display, sp->window );
 
     sp->dec_type = fli_boxtype2frametype( ob->boxtype );
-    fl_drw_frame( sp->dec_type, ob->x, ob->y, ob->w, ob->h, ob->col2, ob->bw );
+    fl_draw_frame( sp->dec_type, ob->x, ob->y, ob->w, ob->h, ob->col2, ob->bw );
 }
 
 
@@ -522,6 +522,10 @@ handle_canvas( FL_OBJECT * ob,
 
     switch ( event )
     {
+        case FL_ATTRIB :
+            ob->align = fl_to_outside_lalign( ob->align );
+            break;
+
         case FL_DRAW:
             if ( ob->col1 != FL_NoColor )
                 sp->xswa.background_pixel = fl_get_pixel( ob->col1 );
