@@ -138,9 +138,6 @@ enum {
 
 /* events.c or event related */
 
-FL_OBJECT * fli_handled_obj;
-FL_OBJECT * fli_handled_parent;
-
 void fli_obj_queue_delete( void );
 
 void fli_event_queue_delete( void );
@@ -326,37 +323,37 @@ int fli_get_pos_in_string( int,
                            int *,
                            int * );
 
-int fli_drw_stringTAB( Window,
-                       GC,
-                       int,
-                       int,
-                       int,
-                       int,
-                       const char *,
-                       int,
-                       int );
+int fli_draw_stringTAB( Window,
+                        GC,
+                        int,
+                        int,
+                        int,
+                        int,
+                        const char *,
+                        int,
+                        int );
 
-int fli_drw_string( int,
-                    FL_Coord,
-                    FL_Coord,
-                    FL_Coord,
-                    FL_Coord,
-                    int,
-                    FL_COLOR,
-                    FL_COLOR,
-                    FL_COLOR,
-                    int,
-                    int,
-                    int,
-                    int,
-                    int,
-                    const char *,
-                    int,
-                    int,
-                    int,
-                    FL_COLOR );
+int fli_draw_string( int,
+                     FL_Coord,
+                     FL_Coord,
+                     FL_Coord,
+                     FL_Coord,
+                     int,
+                     FL_COLOR,
+                     FL_COLOR,
+                     FL_COLOR,
+                     int,
+                     int,
+                     int,
+                     int,
+                     int,
+                     const char *,
+                     int,
+                     int,
+                     int,
+                     FL_COLOR );
 
-int fli_get_maxpixel_line( void );
+int fli_get_max_pixels_line( void );
 
 int fli_get_string_widthTABfs( XFontStruct *,
                                const char *,
@@ -421,19 +418,19 @@ enum {
 void fli_calc_slider_size( FL_OBJECT *,
                            FLI_SCROLLBAR_KNOB * );
 
-void fli_drw_slider( FL_OBJECT *,
-                     FL_COLOR,
-                     FL_COLOR,
-                     const char *,
-                     int );
+void fli_draw_slider( FL_OBJECT *,
+                      FL_COLOR,
+                      FL_COLOR,
+                      const char *,
+                      int );
 
-void fli_drw_checkbox( int      type,
-                       FL_Coord x,
-                       FL_Coord y,
-                       FL_Coord w,
-                       FL_Coord h,
-                       FL_COLOR col,
-                       int      bw );
+void fli_draw_checkbox( int      type,
+                        FL_Coord x,
+                        FL_Coord y,
+                        FL_Coord w,
+                        FL_Coord h,
+                        FL_COLOR col,
+                        int      bw );
 
 void fli_set_global_clipping( FL_Coord,
                               FL_Coord,
@@ -867,7 +864,7 @@ FL_RECT * fli_intersect_rects( const FL_RECT *,
 void fli_xyplot_nice_label( float,
                             int,
                             float,
-                                   char * );
+                            char * );
 
 void fli_xyplot_compute_data_bounds( FL_OBJECT *,
                                      int *,
@@ -1103,7 +1100,6 @@ void fli_set_ul_property( int prop,
 
 int fli_is_valid_dir( const char * name );
 
-
 #endif /* ! defined FL_INTERNAL_H */
 
 
