@@ -36,10 +36,10 @@
 #include "private/flvasprintf.h"
 
 
-#define PointToPixel( a )     FL_crnd( ( a ) * fli_dpi / 72.0   )
-#define MMToPixel( a )        FL_crnd( ( a ) * fli_dpi / 25.4   )
-#define CMMToPixel( a )       FL_crnd( ( a ) * fli_dpi / 2540.0 )
-#define CPointToPixel( a )    FL_crnd( ( a ) * fli_dpi / 7200.0 )
+#define PointToPixel( a )     FL_crnd( ( a ) * fl_dpi / 72.0   )
+#define MMToPixel( a )        FL_crnd( ( a ) * fl_dpi / 25.4   )
+#define CMMToPixel( a )       FL_crnd( ( a ) * fl_dpi / 2540.0 )
+#define CPointToPixel( a )    FL_crnd( ( a ) * fl_dpi / 7200.0 )
 
 static FL_FORM * create_new_form( FL_Coord,
                                   FL_Coord );
@@ -1371,9 +1371,12 @@ fl_show_form_window( FL_FORM * form )
         if ( obj->objclass == FL_FORMBROWSER )
             fl_redraw_object( obj );
 
+    /* Check if there's an object we can make the object that has the focus,
+       it must be an input object and be active and visible */
+
     if ( ! form->focusobj )
         for ( obj = form->first; obj; obj = obj->next )
-            if ( obj->input && obj->active )
+            if ( obj->input && obj->active && obj->visible )
             {
                 fl_set_focus_object( form, obj );
                 break;
