@@ -58,7 +58,7 @@ enum {
 
     /* WM_DELETE_WINDOW callback return */
 
-    FL_IGNORE      = -1,
+    FL_IGNORE      = -1
 };
 
 /* Max  directory length  */
@@ -154,14 +154,14 @@ typedef enum {
 typedef enum {
     FL_PLACE_FREE       =   0,      /* size remain resizable      */
     FL_PLACE_MOUSE      =   1,      /* mouse centered on form     */
-    FL_PLACE_CENTER     =   2,      /* center of the screen       */
-    FL_PLACE_POSITION   =   4,      /* specific position          */
-    FL_PLACE_SIZE       =   8,      /* specific size              */
-    FL_PLACE_GEOMETRY   =  16,      /* specific size and position */
-    FL_PLACE_ASPECT     =  32,      /* keep aspect ratio          */
-    FL_PLACE_FULLSCREEN =  64,      /* scale to fit to screen     */
-    FL_PLACE_HOTSPOT    = 128,      /* so mouse fall on (x,y)     */
-    FL_PLACE_ICONIC     = 256,      /* start in iconified form    */
+    FL_PLACE_CENTER     =   2,         /* center of the screen       */
+    FL_PLACE_POSITION   =   4,         /* specific position          */
+    FL_PLACE_SIZE       =   8,         /* specific size              */
+    FL_PLACE_GEOMETRY   =  16,         /* specific size and position */
+    FL_PLACE_ASPECT     =  32,         /* keep aspect ratio          */
+    FL_PLACE_FULLSCREEN =  64,         /* scale to fit to screen     */
+    FL_PLACE_HOTSPOT    = 128,         /* so mouse fall on (x,y)     */
+    FL_PLACE_ICONIC     = 256,         /* start in iconified form    */
 
     /* Modifiers */
 
@@ -178,7 +178,7 @@ typedef enum {
 enum {
     FL_FULLBORDER = 1,      /* normal                                  */
     FL_TRANSIENT,           /* set TRANSIENT_FOR property              */
-    FL_NOBORDER,            /* use override_redirect to supress decor. */
+    FL_NOBORDER             /* use override_redirect to supress decor. */
  };
 
 /* All box types */
@@ -261,7 +261,7 @@ FL_EXPORT int fl_to_inside_lalign( int align );
 
 FL_EXPORT int fl_to_outside_lalign( int align );
 
-/* Mouse buttons. Don't have to be consecutive */
+/* Mouse buttons */
 
 enum {
     FL_MBUTTON1 = 1,
@@ -283,14 +283,14 @@ enum {
 #define FL_SCROLLUPMOUSE     FL_SCROLLUP_MOUSE
 #define FL_SCROLLDOWNMOUSE   FL_SCROLLDOWN_MOUSE
 
-/* control when to return input, slider and dial etc. object. */
+/* Flags for when to return an object */
 
-#define FL_RETURN_NONE         0U
-#define FL_RETURN_CHANGED      1U
-#define FL_RETURN_END          2U
-#define FL_RETURN_END_CHANGED  4U
-#define FL_RETURN_SELECTION    8U
-#define FL_RETURN_DESELECTION  16U
+#define FL_RETURN_NONE            0U
+#define FL_RETURN_CHANGED         1U
+#define FL_RETURN_END             2U
+#define FL_RETURN_END_CHANGED     4U
+#define FL_RETURN_SELECTION       8U
+#define FL_RETURN_DESELECTION    16U
 #define FL_RETURN_TRIGGERED    1024U
 #define FL_RETURN_ALWAYS       ( ~ FL_RETURN_END_CHANGED )
 
@@ -458,6 +458,7 @@ typedef enum {
 	FL_VIOLET,
 	FL_WHITESMOKE,
 	FL_YELLOWGREEN,
+    FL_COLOR_CHOOSER_COLOR = 255,
     FL_FREE_COL1 = 256,
     FL_FREE_COL2,
     FL_FREE_COL3,
@@ -537,7 +538,6 @@ typedef enum {
 	FL_MOVE      = FL_MOTION,
     FL_KEYBOARD  = FL_KEYPRESS,
     FL_MOUSE     = FL_UPDATE
-
 } FL_EVENTS;
 
 
@@ -1351,6 +1351,8 @@ FL_EXPORT int fl_set_font_name_f( int          n,
 								  const char * fmt,
 								  ... );
 
+FL_EXPORT const char * fl_get_font_name( int n );
+
 FL_EXPORT void fl_set_font( int numb,
                             int size );
 
@@ -1404,45 +1406,49 @@ FL_EXPORT void fl_get_align_xy( int   align,
 
 FL_EXPORT int fl_get_label_char_at_mouse( FL_OBJECT * obj );
 
-FL_EXPORT void fl_drw_text( int          align,
-                            FL_Coord     x,
-                            FL_Coord     y,
-                            FL_Coord     w,
-                            FL_Coord     h,
-                            FL_COLOR     c,
-                            int          style,
-                            int          size,
-                            const char * istr );
+#define fl_drw_text fl_draw_text
+FL_EXPORT void fl_draw_text( int          align,
+							 FL_Coord     x,
+							 FL_Coord     y,
+							 FL_Coord     w,
+							 FL_Coord     h,
+							 FL_COLOR     c,
+							 int          style,
+							 int          size,
+							 const char * istr );
 
-FL_EXPORT void fl_drw_text_beside( int          align,
-                                   FL_Coord     x,
-                                   FL_Coord     y,
-                                   FL_Coord     w,
-                                   FL_Coord     h,
-                                   FL_COLOR     c,
-                                   int          style,
-                                   int          size,
-                                   const char * str );
+#define fl_drw_text_beside fl_draw_text_beside
+FL_EXPORT void fl_draw_text_beside( int          align,
+									FL_Coord     x,
+									FL_Coord     y,
+									FL_Coord     w,
+									FL_Coord     h,
+									FL_COLOR     c,
+									int          style,
+									int          size,
+									const char * str );
 
-FL_EXPORT void fl_drw_text_cursor( int          align,
-                                   FL_Coord     x,
-                                   FL_Coord     y,
-                                   FL_Coord     w,
-                                   FL_Coord     h,
-                                   FL_COLOR     c,
-                                   int          style,
-                                   int          size,
-                                   const char * str,
-                                   int          cc,
-                                   int          pos );
+#define fl_drw_text_cursor fl_draw_text_cursor
+FL_EXPORT void fl_draw_text_cursor( int          align,
+									FL_Coord     x,
+									FL_Coord     y,
+									FL_Coord     w,
+									FL_Coord     h,
+									FL_COLOR     c,
+									int          style,
+									int          size,
+									const char * str,
+									FL_COLOR     cc,
+									int          pos );
 
-FL_EXPORT void fl_drw_box( int      style,
-                           FL_Coord x,
-                           FL_Coord y,
-                           FL_Coord w,
-                           FL_Coord h,
-                           FL_COLOR c,
-                           int      bw_in );
+#define fl_draw_box fl_draw_box
+FL_EXPORT void fl_draw_box( int      style,
+							FL_Coord x,
+							FL_Coord y,
+							FL_Coord w,
+							FL_Coord h,
+							FL_COLOR c,
+							int      bw_in );
 
 typedef void ( * FL_DRAWPTR )( FL_Coord,
                                FL_Coord,
@@ -1519,6 +1525,9 @@ FL_EXPORT void fl_show_errors( int y );
 #define FL_nint( a )              ( ( int ) ( ( a ) > 0 ?               \
                                               ( ( a ) + 0.5 ) :         \
                                               ( ( a ) - 0.5 ) ) )
+#define FL_nlong( a )             ( ( long ) ( ( a ) > 0 ?              \
+                                               ( ( a ) + 0.5 ) :        \
+                                               ( ( a ) - 0.5 ) ) )
 #define FL_clamp( a, amin, amax ) ( ( a ) < ( amin ) ?                  \
                                     ( amin ) : ( ( a ) > ( amax ) ?     \
                                                  ( amax ) : ( a ) ) )
