@@ -125,6 +125,12 @@ FL_EXPORT int fl_scrh,      /* screen dimension in pixels */
               fl_scrw;
 FL_EXPORT int fl_vmode;
 
+#define fl_visual    ( fl_state[ fl_vmode ].xvinfo->visual )
+#define fl_colormap  ( fl_state[ fl_vmode ].colormap )
+
+#define fl_get_visual( )    ( fl_state[ fl_vmode ].xvinfo->visual )
+#define fl_get_colormap( )  ( fl_state[ fl_vmode ].colormap )
+
 
 /* Current version only runs in single visual mode */
 
@@ -136,6 +142,9 @@ FL_EXPORT FL_State fl_state[ ];
 
 FL_EXPORT char *fl_ul_magic_char;
 
+FL_EXPORT double fl_dpi;
+#define fl_get_dpi( ) ( fl_dpi )
+
 FL_EXPORT int fl_mode_capable( int mode,
                                int warn );
 
@@ -250,8 +259,12 @@ FL_EXPORT void fl_dashedlinestyle( const char * dash,
 FL_EXPORT void fl_update_display( int block );
 
 
-#define fl_diagline( x, y, w, h, c )  \
-    fl_line( x, y, ( x ) + ( w ) - 1, ( y ) + ( h ) - 1, c )
+#define fl_diagline( x, y, w, h, c )                                          \
+    do                                                                        \
+    {                                                                         \
+        FL_COORD fli_x = ( x ), fli_y = ( y );                                \
+        fl_line( fli_x, fli_y, fli_x + ( w ) - 1, fli_y + ( h ) - 1, ( c ) ); \
+    } while ( 0 )
 
 /* Line attributes */
 
@@ -351,13 +364,14 @@ FL_EXPORT void fl_pieslice( int      fill,
 
 /* High level drawing routines */
 
-FL_EXPORT void fl_drw_frame( int      style,
-                             FL_Coord x,
-                             FL_Coord y,
-                             FL_Coord w,
-                             FL_Coord h,
-                             FL_COLOR c,
-                             int      bw );
+#define fl_drw_frame fl_draw_frame
+FL_EXPORT void fl_draw_frame( int      style,
+                              FL_Coord x,
+                              FL_Coord y,
+                              FL_Coord w,
+                              FL_Coord h,
+                              FL_COLOR c,
+                              int      bw );
 
 /*
  * Interfaces
@@ -461,15 +475,15 @@ FL_EXPORT void fl_wintitle( Window       win,
                             const char * title );
 
 FL_EXPORT void fl_wintitle_f( Window       win,
-							  const char * fmt,
-							  ... );
+                              const char * fmt,
+                              ... );
 
 FL_EXPORT void fl_winicontitle( Window       win,
                                 const char * title );
 
 FL_EXPORT void fl_winicontitle_f( Window       win,
-								  const char * fmt,
-								  ... );
+                                  const char * fmt,
+                                  ... );
 
 FL_EXPORT void fl_winposition( FL_Coord x,
                                FL_Coord y );
@@ -771,7 +785,7 @@ FL_EXPORT void fl_set_clipping( FL_Coord x,
                                 FL_Coord w,
                                 FL_Coord h );
 
-FL_EXPORT void fl_unset_clipping( );
+FL_EXPORT void fl_unset_clipping( void );
 
 FL_EXPORT void fl_set_text_clipping( FL_Coord x,
                                      FL_Coord y,
@@ -872,3 +886,11 @@ typedef struct {
 #define FL_RGB2PIXEL  FL_RGB2PIXEL_
 
 #endif /* ! defined FL_XBASIC_H */
+
+
+/*
+ * Local variables:
+ * tab-width: 4
+ * indent-tabs-mode: nil
+ * End:
+ */
