@@ -246,6 +246,10 @@ handle_menu( FL_OBJECT * ob,
 
     switch ( event )
     {
+        case FL_ATTRIB :
+            ob->align = fl_to_inside_lalign( ob->align );
+            break;
+
         case FL_DRAW:
             /* Draw the object */
 
@@ -257,22 +261,22 @@ handle_menu( FL_OBJECT * ob,
             else
                 col = ob->col1;
 
-            fl_drw_box( boxtype, ob->x, ob->y, ob->w, ob->h, col, ob->bw );
-            fl_drw_text( ob->align, ob->x, ob->y, ob->w, ob->h,
-                         ob->lcol, ob->lstyle, ob->lsize, ob->label );
+            fl_draw_box( boxtype, ob->x, ob->y, ob->w, ob->h, col, ob->bw );
+            fl_draw_text( ob->align, ob->x, ob->y, ob->w, ob->h,
+                          ob->lcol, ob->lstyle, ob->lsize, ob->label );
 
             if ( sp->showsymbol )
             {
                 int dm = 0.85 * FL_min( ob->w, ob->h );
 
-                fl_drw_text( 0, ob->x + ob->w - dm - 1, ob->y + 1,
-                             dm, dm, col, 0, 0, "@menu" );
+                fl_draw_text( 0, ob->x + ob->w - dm - 1, ob->y + 1,
+                              dm, dm, col, 0, 0, "@menu" );
             }
             break;
 
         case FL_ENTER:
             if ( ob->type == FL_TOUCH_MENU && do_menu( ob ) > 0 )
-                    ret |= FL_RETURN_CHANGED;
+                ret |= FL_RETURN_CHANGED;
             break;
 
         case FL_PUSH:
@@ -822,7 +826,10 @@ fl_get_menu( FL_OBJECT * ob )
     }
 #endif
 
-    return val_to_index( ob, sp->val );
+    if ( ISPUP( sp ) )
+        return sp->val;
+
+    return sp->val > 0 && sp->val <= sp->numitems ? sp->mval[ sp->val ] : -1;
 }
 
 
