@@ -31,7 +31,6 @@
 
 #include "include/forms.h"
 #include "flinternal.h"
-#include <string.h>
 #include "private/flvasprintf.h"
 
 
@@ -39,20 +38,27 @@
 
 extern FL_FORM * fli_fast_free_object;     /* defined in forms.c */
 
+extern FL_OBJECT * fli_handled_obj;        /* defined in  events.c */
+extern FL_OBJECT * fli_handled_parent;     /* defined in  events.c */
+
 static void redraw( FL_FORM *,
                     int );
 static void lose_focus( FL_OBJECT * );
-static void get_object_rect( FL_OBJECT *,
-                             XRectangle *,
-                             int );
-static XRectangle * get_label_rect( FL_OBJECT  * obj,
-                                    XRectangle * rect );
-static int objects_intersect( FL_OBJECT *,
-                              FL_OBJECT * );
+static void get_object_rect( const FL_OBJECT * obj,
+                             XRectangle      * rect,
+                             int               extra );
+static XRectangle * get_label_rect( const FL_OBJECT  * obj,
+                                    XRectangle       * rect );
+static int objects_intersect( const FL_OBJECT *,
+                              const FL_OBJECT * );
 static void mark_object_for_redraw( FL_OBJECT * );
-static int object_is_under( FL_OBJECT * );
+static int object_is_under( const FL_OBJECT * );
 static void checked_hide_tooltip( FL_OBJECT *,
                                   XEvent    * );
+static int prep_recalc( FL_FORM   * form,
+                        FL_OBJECT * start_obj );
+static void finish_recalc( FL_FORM   * form,
+                           FL_OBJECT * start_obj );
 
 static FL_OBJECT *refocus;
 
@@ -76,9 +82,9 @@ static FL_RECT *tmp_rects = NULL;
                                     && ( form )->frozen == 0 )
 
 
-/* Macro for checking if a label is to be consider to be "outside" of its
-   object for redrawing purposes. When a label is outside its object and
-   we change the position or size of the object or the text, style or
+/* Macro for checking if a label is to be considered to be "outside" of its
+   object for redrawing purposes. When a label is outside of its object and
+   we change the position or size of the object, the text, or style or
    font size of the label then other objects under the label also need
    to be redrawn. In priciple calling fl_is_outside_lalign() should do
    the job but there are some semi-transparent objects which we need to
@@ -112,7 +118,7 @@ bg_object( FL_FORM * form )
 
 
 /***************************************
- * Creates an object - NOT FOR USE BY USERS OF THE LIBRARY!
+ * Creates an object - NOT MEANT FOR USE BY USERS OF THE LIBRARY!
  ***************************************/
 
 FL_OBJECT *
@@ -157,19 +163,19 @@ fl_make_object( int            objclass,
             break;
 
         case FL_COORD_MM :
-            fli_scale_object( obj, fli_dpi / 25.4, fli_dpi / 25.4 );
+            fli_scale_object( obj, fl_dpi / 25.4, fl_dpi / 25.4 );
             break;
 
         case FL_COORD_POINT :
-            fli_scale_object( obj, fli_dpi / 72.0, fli_dpi / 72.0 );
+            fli_scale_object( obj, fl_dpi / 72.0, fl_dpi / 72.0 );
             break;
 
         case FL_COORD_centiPOINT :
-            fli_scale_object( obj, fli_dpi / 7200.0, fli_dpi / 7200.0 );
+            fli_scale_object( obj, fl_dpi / 7200.0, fl_dpi / 7200.0 );
             break;
 
         case FL_COORD_centiMM :
-            fli_scale_object( obj, fli_dpi / 2540.0, fli_dpi / 2540.0 );
+            fli_scale_object( obj, fl_dpi / 2540.0, fl_dpi / 2540.0 );
             break;
 
         default:
@@ -553,6 +559,7 @@ fl_delete_object( FL_OBJECT * obj )
     }
 
     lose_focus( obj ); 
+
     if ( obj == fli_int.pushobj )
         fli_int.pushobj = NULL;
     if ( obj == fli_int.mouseobj )
@@ -699,7 +706,8 @@ fl_free_object( FL_OBJECT * obj )
 
     if ( obj == fli_handled_obj )
         fli_handled_obj = NULL;
-    if ( obj == fli_handled_parent )        fli_handled_parent = NULL;
+    if ( obj == fli_handled_parent )
+        fli_handled_parent = NULL;
 
     fl_free( obj );
 }
@@ -1153,7 +1161,7 @@ fl_set_object_lcol( FL_OBJECT * obj,
 
         for ( obj = obj->next; obj && obj->objclass != FL_END_GROUP;
               obj = obj->next )
-            fl_set_object_lcolor( obj, lcol );
+            fl_set_object_lcol( obj, lcol );
 
         if ( form )
             fl_unfreeze_form( form );
@@ -1974,7 +1982,7 @@ fl_get_focus_object( FL_FORM * form )
 
 /***************************************
  * Returns an object of type 'find' in a form, starting at 'obj'.
- * If find_object() does not return an object the event that
+ * If the function does not return an object the event that
  * triggered the call will be eaten. This is how the deactived
  * and inactive objects reject events.
  * Modify with care!
@@ -2162,9 +2170,10 @@ mark_object_for_redraw( FL_OBJECT * obj )
        the object(s) it is beneath and also mark them for a redraw. For the
        special case that the object to be redraw is the first object of
        the form (i.e. the one for the background) we don't have to check
-       if the other object are on top of it, they all are and need a redraw. */
+       if the other object are on top of it, they all are. */
 
     if ( obj == bg_object( obj->form ) )
+    {
         for ( o = obj->next; o; o = o->next )
         {
             if (    ! o->visible
@@ -2175,19 +2184,39 @@ mark_object_for_redraw( FL_OBJECT * obj )
 
             obj->redraw = 1;
         }
+    }
     else if ( obj->is_under )
+    {
+        /* If it hasn't been done yet pre-calculate the sizes of all
+           objects possibly concerned */
+
+        int need_finish = prep_recalc( obj->form, obj );
+        int cnt = 0;
+
         for ( o = obj->next; o; o = o->next )
         {
             if (    o->redraw
                  || ! o->visible
-                 || o->parent
+                 || ( o->parent && ! o->parent->visible )
                  || o->objclass == FL_BEGIN_GROUP
                  || o->objclass == FL_END_GROUP )
                 continue;
 
             if ( objects_intersect( obj, o ) )
+            {
                 mark_object_for_redraw( o );
+
+                /* Since we know how many objects are on top of our object
+                   we can stop if all of them have been marked for redraw. */
+
+                if ( ++cnt >= obj->is_under )
+                    break;
+            }
         }
+
+        if ( need_finish )
+            finish_recalc( obj->form, obj );
+    }
 }
 
 
@@ -2211,8 +2240,16 @@ fl_redraw_object( FL_OBJECT * obj )
     {
         FL_OBJECT *o = obj->next;
 
+        /* If it hasn't been done yet pre-calculate the sizes of all
+            objects possibly concerned */
+
+        int need_finish = prep_recalc( o->form, o );
+
         for ( ; o && o->objclass != FL_END_GROUP; o = o->next )
             mark_object_for_redraw( o );
+
+        if ( need_finish )
+            finish_recalc( obj->form, obj->next ); 
     }
     else
         mark_object_for_redraw( obj );
@@ -2222,34 +2259,37 @@ fl_redraw_object( FL_OBJECT * obj )
 
 
 /***************************************
- * Function to test if the areas of two objects (and their labels) intersect
+ * Function to test if the areas of two objects (including their labels if
+ * they're outside the object) intersect
  ***************************************/
 
 static int
-objects_intersect( FL_OBJECT * obj1,
-                   FL_OBJECT * obj2 )
+objects_intersect( const FL_OBJECT * obj1,
+                   const FL_OBJECT * obj2 )
 {
-    FL_RECT r[ 2 ];
-
     if ( tmp_vdata )
     {
-        r[ 0 ] = * ( FL_RECT * ) obj1->u_vdata;
-        r[ 1 ] = * ( FL_RECT * ) obj2->u_vdata;
+        FL_RECT *r1 = obj1->u_vdata,
+                *r2 = obj2->u_vdata;
+
+        return    r1->x + r1->width  > r2->x
+               && r2->x + r2->width  > r1->x
+               && r1->y + r1->height > r2->y
+               && r2->y + r2->height > r1->y;
+
     }
     else
     {
-        get_object_rect( obj1, r,     0 );
-        get_object_rect( obj2, r + 1, 0 );
-    }
+        FL_RECT r1, r2;
 
-    return      (    (    r[ 0 ].x <= r[ 1 ].x
-                       && r[ 0 ].x + r[ 0 ].width > r[ 1 ].x )
-                  || (    r[ 1 ].x <= r[ 0 ].x
-                       && r[ 1 ].x + r[ 1 ].width > r[ 0 ].x ) )
-            && (    (    r[ 0 ].y <= r[ 1 ].y
-                      && r[ 0 ].y + r[ 0 ].height > r[ 1 ].y )
-                 || (    r[ 1 ].y <= r[ 0 ].y
-                      && r[ 1 ].y + r[ 1 ].height > r[ 0 ].y ) );
+        get_object_rect( obj1, &r1, 0 );
+        get_object_rect( obj2, &r2, 0 );
+
+        return    r1.x + r1.width  > r2.x
+               && r2.x + r2.width  > r2.x
+               && r1.y + r1.height > r2.y
+               && r2.y + r2.height > r1.y;
+    }
 }
 
 
@@ -2619,7 +2659,7 @@ handle_object( FL_OBJECT * obj,
         case FL_FOCUS:
             /* 'refocus' is set if on the last FL_UNFOCUS it was found
                that the text in the input field didn't validate. In that
-               case the focus has to go back to that field instead to a
+               case the focus has to go back to that field and *not* to a
                different one */
 
             if ( refocus && refocus->form )
@@ -3045,11 +3085,11 @@ fl_draw_object_label( FL_OBJECT * obj )
     align = fl_to_outside_lalign( obj->align );
 
     if ( fl_is_inside_lalign( obj->align ) )
-        fl_drw_text( align, obj->x, obj->y, obj->w, obj->h,
-                     obj->lcol, obj->lstyle, obj->lsize, obj->label );
+        fl_draw_text( align, obj->x, obj->y, obj->w, obj->h,
+                      obj->lcol, obj->lstyle, obj->lsize, obj->label );
     else
-        fl_drw_text_beside( align, obj->x, obj->y, obj->w, obj->h,
-                            obj->lcol, obj->lstyle, obj->lsize, obj->label );
+        fl_draw_text_beside( align, obj->x, obj->y, obj->w, obj->h,
+                             obj->lcol, obj->lstyle, obj->lsize, obj->label );
 }
 
 
@@ -3059,9 +3099,9 @@ fl_draw_object_label( FL_OBJECT * obj )
 void
 fl_draw_object_label_outside( FL_OBJECT * obj )
 {
-    fl_drw_text_beside( fl_to_outside_lalign( obj->align ),
-                        obj->x, obj->y, obj->w, obj->h,
-                        obj->lcol, obj->lstyle, obj->lsize, obj->label );
+    fl_draw_text_beside( fl_to_outside_lalign( obj->align ),
+                         obj->x, obj->y, obj->w, obj->h,
+                         obj->lcol, obj->lstyle, obj->lsize, obj->label );
 }
 
 
@@ -3087,13 +3127,15 @@ fl_call_object_callback( FL_OBJECT * obj )
  * its successors in the forms list of objects (objects are always sorted in
  * a way that objects earlier in the list are drawn under those following
  * it). We don't need to look at objects that have a parent since for
- * them the tests for the parent objects will do.
+ * them the tests for the parent objects will do. It returns the number
+ * of objects that are "over" the object.
  ***************************************/
 
 static int
-object_is_under( FL_OBJECT * obj )
+object_is_under( const FL_OBJECT * obj )
 {
     FL_OBJECT *o;
+    int cnt = 0;
 
     /* The first object of a form is always below all others */
 
@@ -3113,51 +3155,71 @@ object_is_under( FL_OBJECT * obj )
             continue;
 
         if ( objects_intersect( obj, o ) )
-            return 1;
+            cnt++;
     }
 
-    return 0;
+    return cnt;
 }
 
 
 /***************************************
- * Helper function for fli_recalc_intersections() - without this is a
- * O(N^2) operation with respect to the recalculations of the N
- * object bounding boxes. Here we use that the 'u_vdata' pointers
- * of the objects don't get used during fli_recalc_intersections()
- * and replace them all by pointers to pre-calculated bounding
- * boxes, thus reducing the number of recalculations to N (in
- * objects_intersect() it gets checked if 'tmp_vdata' is non-NULL
- * and then uses the pre-calculated bounding boxes).
+ * Helper function for fli_recalc_intersections() and other functions -
+ * without this is a O(N^2) operation with respect to the recalculations
+ * of the N object bounding boxes. Here we use that the 'u_vdata' pointers
+ * of the objects don't get used during fli_recalc_intersections() and
+ * replace them all by pointers to pre-calculated bounding boxes, thus
+ * reducing the number of recalculations to N (in objects_intersect() it
+ * gets checked if 'tmp_vdata' is non-NULL and then uses the pre-calculated
+ * bounding boxes).
  ***************************************/
 
-static void
-prep_recalc( FL_FORM * form )
+static int
+prep_recalc( FL_FORM   * form,
+             FL_OBJECT * start_obj )
 {
     FL_OBJECT *obj;
     int cnt = 0;
     int i = 0;
 
-    /* Couny how many objects the form contains */
+    if ( ! form || tmp_vdata )
+        return 0;
 
-    for ( obj = bg_object( form ); obj; obj = obj->next )
+    if ( ! start_obj )
+        start_obj = bg_object( form );
+
+    /* Count how many objects the form contains */
+
+    for ( obj = start_obj; obj; obj = obj->next )
         cnt++;
 
+    if ( cnt < 2 )
+        return 0;
+
     /* Get memory for temporary storing the 'u_vdata' pointers of all objects
        and as many FL_RECT's */
 
-    tmp_vdata = fl_malloc( cnt * sizeof *tmp_vdata );
-    tmp_rects = fl_malloc( cnt * sizeof *tmp_rects );
+    if ( ( tmp_vdata = fl_malloc( cnt * sizeof *tmp_vdata ) ) )
+    {
+        if ( ! ( tmp_rects = fl_malloc( cnt * sizeof *tmp_rects ) ) )
+        {
+            fli_safe_free( tmp_vdata );
+            return 0;
+        }
+    }
+    else
+        return 0;
 
     /* Save the 'u_vdata' pointers and replace them by pointers to the
        bounding box rectangles */
 
-    for ( obj = bg_object( form ); obj; obj = obj->next )
+    for ( obj = start_obj; obj; obj = obj->next )
     {
         tmp_vdata[ i ] = obj->u_vdata;
         obj->u_vdata = tmp_rects + i;
         get_object_rect( obj, tmp_rects + i++, 0 );
     }
+
+    return 1;
 }
 
 
@@ -3168,7 +3230,8 @@ prep_recalc( FL_FORM * form )
  ***************************************/
 
 static void
-finish_recalc( FL_FORM * form )
+finish_recalc( FL_FORM   * form,
+               FL_OBJECT * start_obj )
 {
     FL_OBJECT *obj;
     int i = 0;
@@ -3176,7 +3239,8 @@ finish_recalc( FL_FORM * form )
     if ( ! tmp_vdata )
         return;
 
-    for ( obj = bg_object( form ); obj; obj = obj->next )
+    for ( obj = start_obj ? start_obj : bg_object( form ); obj;
+          obj = obj->next )
         obj->u_vdata = tmp_vdata[ i++ ];
 
     fli_safe_free( tmp_rects );
@@ -3204,10 +3268,10 @@ fli_recalc_intersections( FL_FORM * form )
     if ( fl_current_form || ! form || ( form && form->frozen ) )
         return;
 
-    prep_recalc( form );
+    prep_recalc( form, NULL );
     for ( obj = bg_object( form ); obj && obj->next; obj = obj->next )
         obj->is_under = object_is_under( obj );
-    finish_recalc( form );
+    finish_recalc( form, NULL );
 }
 
 
@@ -3221,7 +3285,6 @@ fl_move_object( FL_OBJECT * obj,
 {
      FL_Coord x,
               y;
-
      if ( fli_inverted_y )
          dy = - dy;
 
@@ -3479,8 +3542,8 @@ fl_get_object_bbox( FL_OBJECT * obj,
  ***************************************/
 
 static XRectangle *
-get_label_rect( FL_OBJECT  * obj,
-                XRectangle * rect )
+get_label_rect( const FL_OBJECT * obj,
+                XRectangle      * rect )
 {
     int sw,
         sh;
@@ -3533,9 +3596,9 @@ get_label_rect( FL_OBJECT  * obj,
  ***************************************/
 
 static void
-get_object_rect( FL_OBJECT * obj,
-                 FL_RECT   * rect,
-                 int         extra )
+get_object_rect( const FL_OBJECT * obj,
+                 FL_RECT         * rect,
+                 int               extra )
 {
     if (    obj->objclass == FL_FRAME
          || obj->objclass == FL_LABELFRAME
@@ -3553,7 +3616,7 @@ get_object_rect( FL_OBJECT * obj,
     /* Include the label into the box - but only for labels that are not
        within the object. If "inside" labels extend beyond the limits of the
        object things look ugly anyway and it doesn't seem to make too much
-       sense to slow down the program any further for that case. */
+       sense to slow down the program for this case. */
 
     if ( obj->label && *obj->label && OL( obj ) )
     {
@@ -3570,20 +3633,22 @@ void
 fl_set_object_automatic( FL_OBJECT * obj,
                          int         flag )
 {
-    if ( obj->automatic != ( flag ? 1 : 0 ) )
+    flag = flag ? 1 : 0;
+
+    if ( obj->automatic == flag )
+        return;
+
+    obj->automatic = flag;
+
+    if ( obj->form )
     {
-        obj->automatic = flag ? 1 : 0;
-
-        if ( obj->form )
-        {
-            if ( flag )
-                obj->form->num_auto_objects++;
-            else
-                obj->form->num_auto_objects--;
-        }
-
-        fli_recount_auto_objects( );
+        if ( flag )
+            obj->form->num_auto_objects++;
+        else
+            obj->form->num_auto_objects--;
     }
+
+    fli_recount_auto_objects( );
 }
 
 
@@ -3634,12 +3699,16 @@ lose_focus( FL_OBJECT * obj )
 
 
 /***************************************
- * Part of the public interface, not used within the library
+ * Part of the public interface, not used within the library.
+ * Calls a user supplied function on all objects of a form but stops
+ * in between of the function, when called on one of the objects,
+ * returns 0. The function also gets called for objects that mark the
+ * begin and end of a group!
  ***************************************/
 
 void
 fl_for_all_objects( FL_FORM * form,
-                    int       ( * cb )( FL_OBJECT *, void * ),
+                    int       ( * fp )( FL_OBJECT *, void * ),
                     void    * v )
 {
     FL_OBJECT *obj;
@@ -3650,13 +3719,13 @@ fl_for_all_objects( FL_FORM * form,
         return;
     }
 
-    if ( ! cb )
+    if ( ! fp )
     {
         M_err( "fl_for_all_objects", "NULL callback function" );
         return;
     }
 
-    for ( obj = bg_object( form ); obj && ! cb( obj, v ); obj = obj->next )
+    for ( obj = bg_object( form ); obj && ! fp( obj, v ); obj = obj->next )
         /* empty */ ;
 }
 
@@ -3698,10 +3767,10 @@ fl_set_object_helper_f( FL_OBJECT  * obj,
 /***************************************
  * Function for setting the conditions under which an object gets
  * returned (or its callback invoked). If the object has to do
- * additional work on setting te condition (e.g. it has child
- * objects that also need to be set) it has to set up it's own
- * function that then will called in the end. This function should
- * only be called once an object has been created completely!
+ * additional work on setting the condition (e.g. it has child
+ * objects that also need to be set) it has to set up its own
+ * function that then will be called in the end. This function should
+ * only be called once an object has been fully created!
  ***************************************/
 
 int
