@@ -319,7 +319,7 @@ fli_tbox_insert_line( FL_OBJECT  * obj,
     tl->specialGC     = None;
     tl->incomp_esc    = 0;
 
-    /* Check for flags at the start of the line. When we're done 'p'
+    /* Check for flags at the start of the line. When we're done 'p' will
        points to the start of the string to be shown in the textbox. */
 
     while ( *p && *p == sp->specialkey && ! done )
@@ -608,16 +608,16 @@ fli_tbox_add_chars( FL_OBJECT  * obj,
        of the line from the old text and the new text, delete te old line and
        then draw a new one in its place.
 
-       Another question is how to deal with situations where by a previous
-       call with e.g. "@C3" a color was selected and in the next call the
+       Another question is how to deal with situations where, by a previous
+       call with e.g. "@C3", a color was selected and in the next call the
        string to be added starts with a digit, let's say '7'. One possibility
        would be to re-evaluate the combined string to mean "@C37", setting
        a different color. But since in older versions this didn't happen
-       (and some users may rely on this, it is assumed that this isn't the
+       (and some users may rely on this), it is assumed that this isn't the
        users intention and to avoid the two digits to become collated and
        interpreted as the number of a different color "@ " is inserted in
        between the digits, with "@ " treated as a separator between digits
-       (the intended ose of "@ " is to allow lines like "@C3@ 2. Chapter", i.
+       (the intended use of "@ " is to allow lines like "@C3@ 2. Chapter", i.
        e. having a color specification, followed by printable text that starts
        with a digit). */
 
@@ -1684,8 +1684,8 @@ draw_tbox( FL_OBJECT * obj )
     FLI_TBOX_SPEC *sp = obj->spec;
     int i;
 
-    fl_drw_box( obj->boxtype, obj->x, obj->y, obj->w, obj->h,
-                obj->col1, obj->bw );
+    fl_draw_box( obj->boxtype, obj->x, obj->y, obj->w, obj->h,
+                 obj->col1, obj->bw );
 
     XFillRectangle( flx->display, FL_ObjWin( obj ),
                     sp->backgroundGC,
@@ -1719,10 +1719,10 @@ draw_tbox( FL_OBJECT * obj )
             /* The extra horizontal pixels here are due to the function called
                subtracting them! */
 
-            fl_drw_text( 0, obj->x + sp->x - 3,
-                         obj->y + sp->y - sp->yoffset + tl->y + tl->h / 2,
-                         sp->w + 6, 1,
-                         FL_COL1, FL_NORMAL_STYLE, sp->def_size, "@DnLine" );
+            fl_draw_text( 0, obj->x + sp->x - 3,
+                          obj->y + sp->y - sp->yoffset + tl->y + tl->h / 2,
+                          sp->w + 6, 1,
+                          FL_COL1, FL_NORMAL_STYLE, sp->def_size, "@DnLine" );
             continue;
         }
 
@@ -1782,10 +1782,10 @@ draw_tbox( FL_OBJECT * obj )
                          ( fli_dithered( fl_vmode ) && tl->selected ) ?
                          FL_WHITE : tl->color );
 
-        fli_drw_stringTAB( FL_ObjWin( obj ), activeGC,
-                           obj->x + sp->x - sp->xoffset + tl->x,
-                           obj->y + sp->y - sp->yoffset + tl->y + tl->asc,
-                           tl->style, tl->size, tl->text, tl->len, 0 );
+        fli_draw_stringTAB( FL_ObjWin( obj ), activeGC,
+                            obj->x + sp->x - sp->xoffset + tl->x,
+                            obj->y + sp->y - sp->yoffset + tl->y + tl->asc,
+                            tl->style, tl->size, tl->text, tl->len, 0 );
     }
 
     fl_unset_clipping( );
@@ -1864,7 +1864,7 @@ fli_tbox_get_topline( FL_OBJECT * obj )
         return -1;
 
     /* If the box was never shown assume that the very first line will
-       be the one that's goin tp be in topmost position */
+       be the one that's going to be in topmost position */
 
     if ( ! sp->def_height )
         return 0;
